diff --git anon-upload-template.php anon-upload-template.php
index 46c4048..af9ae0a 100755
--- anon-upload-template.php
+++ anon-upload-template.php
@@ -29,6 +29,17 @@ function anon_upload_css() {
 		padding-top: 10px;
 	}
 
+	.page-template-anon-upload-template-php #footer {
+		position: absolute;
+		bottom: 0;
+		right: 0;
+		left: 0;
+	}
+
+	.video-upload {
+		padding-bottom: 70px;
+	}
+
 	.noscript-show p {
 		margin: 0 !important;
 	}
@@ -40,18 +51,12 @@ function anon_upload_css() {
 
 	.video-upload-left {
 		max-width: 550px;
-		margin: 15px;
 	}
 
 	.video-upload-right {
-		margin: -25px 15px 0;
-	}
-	@media screen and ( min-width:941px ) {
-		.video-upload-right {
-			float: right;
-			width: 390px;
-			margin: -25px 0 25px;
-		}
+		float: right;
+		width: 390px;
+		margin: -25px 0 25px;
 	}
 
 	.video-upload p {
@@ -102,11 +107,12 @@ function anon_upload_css() {
 	    color: #333;
 	    background-color: #fff;
 	    padding: 4px;
-	    width: 98%;
+	    width: 329px;
 		max-width: 329px;
 	}
 
 	.video-upload-left ul.cats-checkboxes {
+		margin-left: 130px;
 		height: 150px;
 		overflow: auto;
 	}
@@ -120,9 +126,9 @@ function anon_upload_css() {
 		border-color: #bbb;
 	}
 
-		.video-upload-left #wptv_honey_container {
-			display: none;
-		}
+	.video-upload-left #wptv_honey_container {
+		display: none;
+	}
 
 	#video-upload-form p.last {
 		margin: 5px 80px 25px;
@@ -163,6 +169,10 @@ function anon_upload_css() {
 		display: inline;
 		width: auto;
 	}
+
+	#wptv_video_producer_username {
+		margin: 22px 0;
+	}
 	</style>
 	<?php
 }
@@ -173,7 +183,7 @@ get_header();
 
 $message = '';
 
-if ( !empty($_REQUEST['error']) ) {
+if ( !empty( $_REQUEST['error'] ) ) {
 	$message = (int) $_REQUEST['error'];
 
 	switch ( $message ) {
@@ -208,6 +218,9 @@ if ( !empty($_REQUEST['error']) ) {
 		case 13:
 			$message = "Error: please leave the first field empty. (It helps us know you're not a spammer.)";
 			break;
+		case 14:
+			$message = "Error: invalid WordPress.org username given for Producer.";
+			break;
 	}
 	$message = '<div class="error"><p>' . $message . '</p></div>';
 } elseif ( !empty($_REQUEST['success']) ) {
@@ -306,10 +319,9 @@ if ( !empty($_REQUEST['error']) ) {
 			?>
 		</ul>
 	</div>
-
 	<p>
-		<label for="wptv_video_producer"><?php esc_html_e( 'Video producer' ); ?></label>
-		<input type="text" id="wptv_video_producer" name="wptv_video_producer" value="" />
+		<label for="wptv_video_producer_username"><?php esc_html_e( 'Producer WordPress.org Username' ); ?></label>
+		<input type="text" id="wptv_video_producer_username" name="wptv_video_producer_username" value="" />
 	</p>
 	<p>
 		<label for="wptv_speakers"><?php esc_html_e( 'Speakers' ); ?></label>
diff --git category-wordcamptv.php category-wordcamptv.php
index 53bdcac..6f74079 100755
--- category-wordcamptv.php
+++ category-wordcamptv.php
@@ -16,10 +16,9 @@ global $wptv;
 ?>
 <div class="wptv-hero group">
 	<div class="container">
-		<div class="wptv-category-title">
-			<h2 class="page-title"><?php single_term_title(); ?></h2>
-			<div class="desc"><?php echo category_description(); ?></div>
-		</div>
+
+		<h2 class="page-title"><?php single_term_title(); ?></h2>
+		<div class="desc"><?php echo category_description(); ?></div>
 
 		<?php if ( $featured->have_posts() ) : $featured->the_post(); ?>
 			<div class="main-video">
diff --git front-page.php front-page.php
index 8d12777..81ea289 100755
--- front-page.php
+++ front-page.php
@@ -24,7 +24,7 @@ get_header(); ?>
 			<h3>
 				<a href="<?php the_permalink() ?>" rel="bookmark" title="<?php the_title_attribute(); ?>" class="video-title"><?php the_title(); ?></a>
 				<?php $wptv->the_event( '<strong class="video-event">', '</strong>' ); ?>
-			</h3>
+		</h3>
 		</div><!-- .main-video -->
 		<?php endwhile; // $featured->have_posts ?>
 
diff --git functions.php functions.php
old mode 100755
new mode 100644
index a33be88..86abe50
--- functions.php
+++ functions.php
@@ -164,6 +164,7 @@ class WordPressTV_Theme {
 		global $post;
 
 		$slides_url = get_post_meta( $post->ID, '_wptv_slides_url', true );
+		$producer_username = get_post_meta( $post->ID, '_wptv_producer_username', true );
 		wp_nonce_field( 'edit-video-info', 'video_info_metabox_nonce' );
 
 		?>
@@ -172,7 +173,10 @@ class WordPressTV_Theme {
 			<label for="wptv-slides-url">Slides URL</label>
 			<input type="text" class="widefat" id="wptv-slides-url" name="_wptv_slides_url" value="<?php echo esc_url( $slides_url ); ?>" />
 		</p>
-
+		<p>
+			<label for="wptv-producer-username">Video Producer WordPress.org Username</label>
+			<input type="text" class="widefat" id="wptv-producer-username" name="_wptv_producer_username" value="<?php echo sanitize_user( $producer_username, true ); ?>" />
+		</p>
 		<?php
 	}
 
@@ -198,6 +202,14 @@ class WordPressTV_Theme {
 		} else {
 			delete_post_meta( $post_id, '_wptv_slides_url' );
 		}
+
+		$producer_username = sanitize_user( $_POST['_wptv_producer_username'], true );
+
+		if ( $producer_username ) {
+			update_post_meta( $post_id, '_wptv_producer_username', $producer_username );
+		} else {
+			delete_post_meta( $post_id, '_wptv_producer_username' );
+		}
 	}
 
 	/**
@@ -772,29 +784,12 @@ function wptv_enqueue_scripts() {
 	wp_enqueue_style( 'wptv-ie', get_template_directory_uri() . '/ie6.css', array( 'wptv-style' ) );
 	wp_style_add_data( 'wptv-ie', 'conditional', 'IE 6' );
 
-	wp_register_script( 'wptv-dropdowns', get_template_directory_uri() . '/js/dropdowns.js' );
-	wp_enqueue_script( 'wptv-dropdowns', array( 'jquery' ) );
-	wp_enqueue_script( 'jquery-ui-accordion' );
-
 	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
 		wp_enqueue_script( 'comment-reply' );
 	}
 }
 add_action( 'wp_enqueue_scripts', 'wptv_enqueue_scripts' );
 
-function wptv_menu_script() {
-	?>
-	<script>
-		jQuery(document).ready(function($) {
-				$( "#menu-mobile" ).accordion( {
-					collapsible: true,
-					active: false
-				} );
-		});
-	</script>
-<?php
-}
-add_action( 'wp_head', 'wptv_menu_script' );
 /**
  * Create a nicely formatted and more specific title element text for output
  * in head of document, based on current view.
@@ -846,3 +841,26 @@ function wptv_excerpt_slides( $excerpt ) {
 	return $excerpt;
 }
 add_filter( 'get_the_excerpt', 'wptv_excerpt_slides' );
+
+/**
+ * When given a string, returns boolean based on whether the string matches a valid w.org username
+ *
+ * @param $username
+ *
+ * @return bool
+ */
+function dotorg_username_exists( $username ) {
+	$args = array(
+		'redirection' => 0,
+	);
+	$url = 'https://wordpress.org/grav-redirect.php?user=' . $username;
+	$response = wp_remote_get( $url, $args );
+	$response = wp_remote_retrieve_headers( $response );
+
+	if ( validate_username( $username ) && array_key_exists( 'location', $response ) ) {
+		$result = ( ! strpos( $response['location'], 'd=mm' ) ) ? true : false;
+	} else {
+		$result = false;
+	}
+	return $result;
+}
\ No newline at end of file
diff --git header.php header.php
index 64eefa8..7cbab9d 100755
--- header.php
+++ header.php
@@ -14,7 +14,6 @@ global $wptv;
 
 <head>
 	<meta charset="<?php bloginfo( 'charset' ); ?>">
-	<meta name="viewport" content="width=device-width, initial-scale=1">
 	<title><?php wp_title( '|', true, 'right' ); ?></title>
 
 	<link rel="alternate" type="application/rss+xml" title="<?php esc_attr_e( 'WordPress.tv RSS Feed', 'wptv' ); ?>" href="http://wordpress.tv/feed/" />
@@ -41,10 +40,6 @@ global $wptv;
 			<div id="menu">
 				<?php wp_nav_menu( array( 'theme_location' => 'primary' ) ); ?>
 			</div>
-			<div id="menu-mobile">
-				<span class="open">Navigation</span>
-				<?php wp_nav_menu( array( 'theme_location' => 'primary' ) ); ?>
-			</div>
 
 		</div><!-- .sleeve -->
 	</div><!-- #header -->
diff --git sidebar-single.php sidebar-single.php
index 84a2fe6..14527a9 100755
--- sidebar-single.php
+++ sidebar-single.php
@@ -81,5 +81,16 @@
 						printf( '<a href="%s">Subtitle this video &rarr;</a>', esc_url( add_query_arg( 'video', $video->post_id, home_url( 'subtitle/' ) ) ) );
 					}
 				}
-			?>
+
+			// Credit video producer with link to their w.org profile
+			$producer_username = get_post_meta( get_the_ID(), '_wptv_producer_username', true );
+			$producer_name = ( get_the_terms( get_the_ID(), 'producer' ) ) ? get_the_terms( get_the_ID(), 'producer' )[0]->name : $producer_username;
+
+			if ( $producer_username ) { ?>
+				<h5>Producer</h5>
+				<div class="video-producer">
+					<a href="http://profiles.wordpress.org/<?php esc_attr_e( $producer_username ); ?>"><?php esc_attr_e( $producer_name ); ?></a>
+				</div>
+			<?php } ?>
+
 </div><!-- .secondary-content -->
diff --git style.css style.css
index fc417b9..7865023 100755
--- style.css
+++ style.css
@@ -7,13 +7,6 @@ Author: Automattic
 Author URI: http://automattic.com/
 */
 
-/*
-Media breakpoints:
-large 940
-medium 620
-small 400
-*/
-
 /* meyerweb.com/eric/thoughts/2007/05/01/reset-reloaded/ */
 html, body, div, span, applet, object, iframe,
 h1, h2, h3, h4, h5, h6, p, blockquote, pre,
@@ -216,24 +209,16 @@ form, fieldset, address {
 
 #header {
 	margin-top: 10px;
+	height: 57px;
 }
-@media screen and ( max-width:940px ) {
-	#header {
-		padding: 0 10px;
-	}
-}
-@media screen and ( min-width:601px ) {
-	#header {
-		height: 57px;
-	}
-}
+
 #header h1 {
 	padding-top: 8px;
 	float: left;
 }
 
 #header .sleeve {
-	max-width: 942px;
+	width: 942px;
 	margin: 0 auto;
 }
 
@@ -268,11 +253,9 @@ form, fieldset, address {
 	color: #000 !important;
 }
 
-@media screen and ( min-width:401px ) {
-	#searchform {
-		float: right;
-		margin-left: 15px;
-	}
+#searchform {
+	float: right;
+	margin-left: 15px;
 }
 
 #searchform #searchbox,
@@ -295,52 +278,10 @@ form, fieldset, address {
 	width: 130px;
 }
 
-@media screen and ( max-width:400px ) {
-	#searchform #searchbox,
-	#searchform input#s {
-		width: 95%;
-	}
-}
-
 #searchform #searchbox {
 	margin-top: 15px;
 }
 
-/* Mobile menu */
-@media screen and ( min-width:601px ) {
-	#menu-mobile {
-		display: none;
-	}
-}
-
-@media screen and ( max-width:600px ) {
-	#menu {
-		display: none;
-	}
-	#menu-mobile {
-		display: inline-block;
-	}
-}
-
-#menu-mobile {
-	width: 100%;
-	text-align: center;
-	font-size: 1.8em;
-	line-height: 1.6em;
-	margin: 10px 0 0 0;
-}
-#menu-mobile .open {
-	cursor: pointer;
-	color: #21759b;
-	font-weight: bold;
-	padding: 6px 20px;
-	border: 1px solid;
-}
-#menu-mobile .open:hover {
-	color: #d54e21;
-}
-/* Forms */
-
 input[type=submit], button, .button {
 	text-decoration: none;
 	-moz-border-radius: 5px;
@@ -415,7 +356,6 @@ input[type=submit]:active, button:active, .button:active {
 	);
 }
 
-/* Intro */
 .intro {
 	font-size: 30px;
 	height: 64px;
@@ -1489,12 +1429,10 @@ div.sharedaddy.sd-rating-enabled .sd-like .post-likes-widget, div.sharedaddy.sd-
 	display: none;
 }
 
-/*
 #content {
 	width: 630px;
 	float: left;
 }
-*/
 
 #content .post {
 	margin-bottom: 20px;
@@ -1578,7 +1516,7 @@ div.sharedaddy.sd-rating-enabled .sd-like .post-likes-widget, div.sharedaddy.sd-
 }
 
 #commentform textarea {
-	width: 96%;
+	width: 600px;
 	height: 100px;
 	margin-bottom: 5px;
 }
@@ -1643,29 +1581,26 @@ div.sharedaddy.sd-rating-enabled .sd-like .post-likes-widget, div.sharedaddy.sd-
 	font-size: 10px;
 }
 
+#footer {
+	clear: both;
+	height: 3.5em;
+	margin-bottom: 15px;
+	color: #888;
+}
+
 #footer .automattic {
+	width: 400px;
+	float: right;
+	text-align: right;
 	font-size: 11px;
 	letter-spacing: 0.2em;
-	padding: 13px 2px 0 0;
+	line-height: 3em;
+	padding-top: 13px;
+	padding-right: 2px;
 	text-transform: uppercase;
 	line-height: 28px;
 }
 
-@media screen and ( max-width:920px ) {
-	#footer .automattic {
-		width: 100%;
-		clear: both;
-	}
-}
-
-@media screen and ( min-width:921px ) {
-	#footer .automattic {
-		width: 380px;
-		float: right;
-		text-align: right;
-	}
-}
-
 .menu-footer-container {
 	float: left;
 	line-height: 4em;
@@ -1674,16 +1609,8 @@ div.sharedaddy.sd-rating-enabled .sd-like .post-likes-widget, div.sharedaddy.sd-
 	margin-bottom: 0;
 }
 
-@media screen and ( min-width:621px ) {
-	.menu-footer-container li {
-		display: inline-block;
-	}
-}
-
-@media screen and ( max-width:620px ) {
-	.dot {
-		display: none;
-	}
+.menu-footer-container li {
+	display: inline-block;
 }
 
 .menu-footer-container li:last-of-type .dot {
@@ -1863,37 +1790,20 @@ a {
 }
 
 .container {
-	max-width: 940px;
+	width: 940px;
 	margin: auto;
 }
 
 .primary-content {
+	float: left;
+	width: 700px;
 	margin: 0;
 }
 
-@media screen and ( max-width:940px ) {
-	.primary-content {
-		padding: 0 10px;
-	}
-}
-
-@media screen and ( min-width:941px ) {
-	.primary-content {
-		float: left;
-		max-width: 700px;
-	}
-}
-
 .secondary-content {
-	margin: 0 10px;
-}
-
-@media screen and ( min-width:941px ) {
-	.secondary-content {
-		float: right;
-		width: 170px;
-		margin: 0 0 50px 0;
-	}
+	float: right;
+	width: 170px;
+	margin: 0 0 50px 0;
 }
 
 .miro {
@@ -1939,6 +1849,7 @@ a {
 .nav-previous {
 	float: left;
 }
+
 .primary-content #searchform {
 	float: none;
 	margin: 10px 0;
@@ -2020,7 +1931,7 @@ body, td, p,
 }
 
 .page-title {
-	max-width: 940px;
+	width: 940px;
 	margin: auto;
 }
 
@@ -2187,43 +2098,20 @@ h5 {
 	background: #F0F0F0;
 }
 
-@media screen and ( max-width:940px ) {
-	.wptv-hero {
-		padding: 30px 10px 10px;
-	}
-}
-
 .wptv-hero .main-video {
 	background: #2f2f2f;
 	clear: both;
-}
 
-@media screen and ( min-width:941px ) {
-	.wptv-hero .main-video {
-		float: left;
-	}
+	float: left;
+	width: 575px;
 }
 
 .wptv-hero .main-video .video-player {
 	width: 100% !important;
+	height: 323px !important;
 	margin: 0 !important;
 }
 
-@media screen and ( min-width:601px ) {
-	.wptv-hero .main-video {
-		width: 575px;
-	}
-	.wptv-hero .main-video .video-player {
-		height: 323px !important;
-	}
-}
-
-@media screen and ( max-width:600px ) {
-	.wptv-hero .main-video .video-player {
-		height: auto !important;
-	}
-}
-
 .wptv-hero .main-video .video-player .videopress-placeholder {
 	margin: 0;
 	width: 100% !important;
@@ -2277,18 +2165,9 @@ h5 {
 	display: none;
 }
 
-@media screen and ( min-width:941px ) {
-	.wptv-hero .secondary-videos {
-		float: right;
-		width: 345px;
-	}
-}
-
-@media screen and ( max-width:940px ) {
-	.wptv-hero .secondary-videos {
-		display: inline-block;
-		margin-top: 20px;
-	}
+.wptv-hero .secondary-videos {
+	float: right;
+	width: 345px;
 }
 
 .wptv-hero .secondary-videos h3 {
@@ -2303,18 +2182,12 @@ h5 {
 .wptv-hero .secondary-videos li {
 	font-size: 13px;
 
-	min-height: 78px;
+	min-height: 75px;
 	position: relative;
 
 	margin: 0 auto 23px 0;
 	padding: 0 0 0 142px;
 }
-@media screen and ( min-width:620px ) and ( max-width:940px ) {
-	.wptv-hero .secondary-videos li {
-		width: 25%;
-		float: left;
-	}
-}
 
 .wptv-hero .secondary-videos img {
 	width: 130px;
@@ -2328,12 +2201,6 @@ h5 {
 	opacity: 0.8;
 }
 
-@media screen and ( max-width:940px ) {
-	.wptv-category-title {
-		display: inline-block;
-	}
-}
-
 /* Video lists
 ============================================================= */
 
@@ -2342,6 +2209,8 @@ h5 {
 }
 
 .video-list li {
+	float: left;
+	min-height: 220px;
 	margin-bottom: 20px;
 }
 
@@ -2353,6 +2222,7 @@ h5 {
 .video-list li .video-thumbnail {
 	display: block;
 	width: 100%;
+	height: 100px;
 
 	margin: 0 0 8px 0;
 
@@ -2360,21 +2230,13 @@ h5 {
 	position: relative;
 }
 
-@media screen and ( min-width:941px ) {
-	.video-list.four-col {
-		width: 860px;
-	}
+.video-list.four-col {
+	width: 860px;
 }
 
-@media screen and ( min-width:395px ) {
-	.video-list li {
-		float: left;
-		min-height: 220px;
-	}
-	.video-list.four-col li {
-		width: 160px;
-		margin-right: 20px;
-	}
+.video-list.four-col li {
+	width: 160px;
+	margin-right: 20px;
 }
 
 .secondary-content .video-list .video-title {
@@ -2411,21 +2273,15 @@ h5 {
 	position: relative;
 }
 
-@media screen and ( min-width:621px ) {
-	.archive.video-list .video-thumbnail {
-		position: absolute;
-		top: 0;
-		left: 0;
+.archive.video-list .video-thumbnail {
+	position: absolute;
+	top: 0;
+	left: 0;
 
-		width: 220px;
-		height: 120px;
+	width: 220px;
+	height: 120px;
 
-		margin: 0 20px 0 0;
-	}
-	.archive.video-list .video-description {
-		display: block;
-		padding-left: 240px;
-	}
+	margin: 0 20px 0 0;
 }
 
 .archive.video-list .video-title {
@@ -2433,6 +2289,11 @@ h5 {
 	margin: 4px 0 8px;
 }
 
+.archive.video-list .video-description {
+	display: block;
+	padding-left: 240px;
+}
+
 .archive.video-list .video-date {
 	color: #aaa;
 	display: block;
@@ -2489,15 +2350,15 @@ body:not(.single) .video-info {
 }
 
 /* Video Player and Placeholder */
-@media screen and ( min-width:941px ) {
-	.single .video-player {
-		float: left;
-		width: 940px !important;
-		height: 529px !important;
 
-		overflow: hidden;
-	}
+.single .video-player {
+	float: left;
+	width: 940px !important;
+	height: 529px !important;
+
+	overflow: hidden;
 }
+
 .videopress-placeholder,
 .video-player object {
 	width: 100% !important;
@@ -2638,16 +2499,14 @@ h3#comments {
 	margin: 3px 0 20px 0;
 }
 
-@media screen and ( min-width:941px ) {
-	.category-wordcamptv .secondary-content {
-		float: left;
-		width: 170px;
-	}
+.category-wordcamptv .secondary-content {
+	float: left;
+	width: 170px;
+}
 
-	.category-wordcamptv .primary-content {
-		float: right;
-		margin: 0;
-	}
+.category-wordcamptv .primary-content {
+	float: right;
+	margin: 0;
 }
 
 /* WordCamp Individual Page
@@ -2657,15 +2516,6 @@ h3#comments {
 	margin: 0 auto 13px 0
 }
 
-/* Contact Page
-============================================================= */
-
-@media screen and ( max-width:400px ) {
-	.entry .contact-form textarea {
-		width: 98%;
-	}
-}
-
 /* Secondary Content
 ============================================================= */
 
@@ -2696,7 +2546,7 @@ h3#comments {
 ============================================================= */
 
 .error404 .primary-content {
-	max-width: 940px;
+	width: 940px;
 }
 
 .error404 h2 {
@@ -2732,17 +2582,9 @@ h3#comments {
 
 #footer {
 	background: #F0F0F0;
-	color: #888;
-	margin: 10px 0 0 0;
-	padding: 10px;
-}
 
-@media screen and ( min-width:921px ) {
-	#footer {
-		clear: both;
-		height: 3.5em;
-		margin-bottom: 15px;
-	}
+	margin: 10px 0 0 0;
+	padding: 10px 0;
 }
 
 #footer .dot {

diff --git plugins/wordpresstv-anon-upload/anon-upload.php plugins/wordpresstv-anon-upload/anon-upload.php
index 18bca59..c1df414 100755
--- plugins/wordpresstv-anon-upload/anon-upload.php
+++ plugins/wordpresstv-anon-upload/anon-upload.php
@@ -47,7 +47,7 @@ class WPTV_Anon_Upload {
 	function validate() {
 		$text_fields = array(
 			'wptv_video_title',
-			'wptv_video_producer',
+			'wptv_video_producer_username',
 			'wptv_speakers',
 			'wptv_event',
 			'wptv_slides_url'
@@ -62,6 +62,10 @@ class WPTV_Anon_Upload {
 			return $this->error( 13 );
 		}
 
+		if ( isset ( $_POST['wptv_video_producer_username'] ) && dotorg_username_exists( $_POST['wptv_video_producer_username'] ) == false ) {
+			return $this->error( 14 );
+		}
+
 		if ( ! is_user_logged_in() ) {
 			if ( empty( $_POST['wptv_uploaded_by'] ) ) {
 				return $this->error( 10 );
@@ -186,23 +190,23 @@ class WPTV_Anon_Upload {
 
 		if ( ! empty( $name_parts['extension'] ) ) {
 			if ( ! in_array( strtolower( $name_parts['extension'] ), array(
-					'avi',
-					'mov',
-					'qt',
-					'mpeg',
-					'mpg',
-					'mpe',
-					'mp4',
-					'm4v',
-					'asf',
-					'asx',
-					'wax',
-					'wmv',
-					'wmx',
-					'ogv',
-					'3gp',
-					'3g2',
-				), true )
+				'avi',
+				'mov',
+				'qt',
+				'mpeg',
+				'mpg',
+				'mpe',
+				'mp4',
+				'm4v',
+				'asf',
+				'asx',
+				'wax',
+				'wmv',
+				'wmx',
+				'ogv',
+				'3gp',
+				'3g2',
+			), true )
 			) {
 				return $this->error( 2 );
 			}
@@ -229,8 +233,7 @@ class WPTV_Anon_Upload {
 		// Add default cat according to the "This is a WC video" checkbox
 		if ( ! empty( $_posted['wptv_video_wordcamp'] ) ) {
 			$anon_post['post_category'] = array( '12784353' ); // add the "WordCampTV" category
-		}
-		else {
+		} else {
 			$anon_post['post_category'] = array( '1' ); // Uncategorized
 		}
 
@@ -269,14 +272,14 @@ class WPTV_Anon_Upload {
 			$anon_author_email = $this->sanitize_text( $_posted['wptv_email'] );
 		}
 
-		$video_title    = $this->sanitize_text( $_posted['wptv_video_title'] );
-		$video_producer = $this->sanitize_text( $_posted['wptv_video_producer'] );
-		$speakers       = $this->sanitize_text( $_posted['wptv_speakers'] );
-		$event          = $this->sanitize_text( $_posted['wptv_event'] );
-		$description    = $this->sanitize_text( $_posted['wptv_video_description'], false );
-		$language       = $this->sanitize_text( $_posted['wptv_language'] );
-		$slides         = $this->sanitize_text( $_posted['wptv_slides_url'] );
-		$ip             = $_SERVER['REMOTE_ADDR'];
+		$video_title             = $this->sanitize_text( $_posted['wptv_video_title'] );
+		$video_producer_username = $this->sanitize_text( $_posted['wptv_video_producer_username'] );
+		$speakers                = $this->sanitize_text( $_posted['wptv_speakers'] );
+		$event                   = $this->sanitize_text( $_posted['wptv_event'] );
+		$description             = $this->sanitize_text( $_posted['wptv_video_description'], false );
+		$language                = $this->sanitize_text( $_posted['wptv_language'] );
+		$slides                  = $this->sanitize_text( $_posted['wptv_slides_url'] );
+		$ip                      = $_SERVER['REMOTE_ADDR'];
 
 		$categories = '';
 		if ( ! empty( $_posted['post_category'] ) && is_array( $_posted['post_category'] ) ) {
@@ -289,18 +292,18 @@ class WPTV_Anon_Upload {
 		}
 
 		$post_meta = array(
-			'attachment_id'   => $attachment_id,
-			'submitted_by'    => $anon_author,
-			'submitted_email' => $anon_author_email,
-			'title'           => $video_title,
-			'producer'        => $video_producer,
-			'speakers'        => $speakers,
-			'event'           => $event,
-			'language'        => $language,
-			'categories'      => $categories,
-			'description'     => $description,
-			'slides'          => $slides,
-			'ip'              => $ip,
+			'attachment_id'     => $attachment_id,
+			'submitted_by'      => $anon_author,
+			'submitted_email'   => $anon_author_email,
+			'title'             => $video_title,
+			'producer_username' => $video_producer_username,
+			'speakers'          => $speakers,
+			'event'             => $event,
+			'language'          => $language,
+			'categories'        => $categories,
+			'description'       => $description,
+			'slides'            => $slides,
+			'ip'                => $ip,
 		);
 
 		$post_meta['video_guid'] = $video_data->guid;
@@ -327,7 +330,7 @@ class WPTV_Anon_Upload {
 
 		$attachment_post = get_post( $meta['attachment_id'] );
 
-		$embed_args = array(
+		$embed_args            = array(
 			'format'  => 'fmt_std',
 			'width'   => 600,
 			'context' => 'admin',
@@ -335,9 +338,15 @@ class WPTV_Anon_Upload {
 		$embed_args['blog_id'] = get_current_blog_id();
 		$embed_args['post_id'] = $meta['attachment_id'];
 
-		// Add slides index to meta (necessary for posts that were uploaded before the field was added)
-		if ( ! array_key_exists( 'slides', $meta ) ) {
-			$meta['slides'] = '';
+		// Add missing indexes to meta (necessary for posts that were uploaded before the fields were added)
+		$new_fields = array(
+			'slides',
+			'producer_username',
+		);
+		foreach ( $new_fields as $field ) {
+			if ( ! array_key_exists( $field, $meta ) ) {
+				$meta[$field] = '';
+			}
 		}
 
 		?>
@@ -401,9 +410,9 @@ class WPTV_Anon_Upload {
 					<tr>
 						<td>
 							<?php
-								if ( function_exists( 'video_embed' ) ) {
-									echo video_embed( $embed_args );
-								}
+							if ( function_exists( 'video_embed' ) ) {
+								echo video_embed( $embed_args );
+							}
 							?>
 						</td>
 					</tr>
@@ -412,13 +421,16 @@ class WPTV_Anon_Upload {
 				<div class="anon-data">
 					<div class="row">
 						<p class="label">Submitted by:<br></p>
+
 						<p class="data">
-							<input type="text" readonly="readonly" value="<?php echo esc_attr( $meta['submitted_by'] ); ?>"/>
+							<input type="text" readonly="readonly"
+							       value="<?php echo esc_attr( $meta['submitted_by'] ); ?>"/>
 						</p>
 					</div>
 
 					<div class="row">
 						<p class="label">Email:</p>
+
 						<p class="data">
 							<a href="mailto:<?php echo esc_attr( $meta['submitted_email'] ); ?>?Subject=Your%20WordPress.tv%20submission"><?php echo esc_html( $meta['submitted_email'] ); ?></a>
 						</p>
@@ -426,13 +438,17 @@ class WPTV_Anon_Upload {
 
 					<div class="row">
 						<p class="label">IP Address:</p>
+
 						<p class="data">
-							<a href="<?php echo esc_url( add_query_arg( array( 'query' => $meta['ip'] ), 'http://en.utrace.de' ) ); ?>" target="_blank"><?php echo esc_html( $meta['ip'] ); ?></a> (opens in new tab, shows location of the IP)
+							<a href="<?php echo esc_url( add_query_arg( array( 'query' => $meta['ip'] ), 'http://en.utrace.de' ) ); ?>"
+							   target="_blank"><?php echo esc_html( $meta['ip'] ); ?></a> (opens in new tab, shows
+							location of the IP)
 						</p>
 					</div>
 
 					<div class="row">
 						<p class="label">Title:</p>
+
 						<p class="data">
 							<input type="text" value="<?php echo esc_attr( $meta['title'] ); ?>"/>
 							<a class="button-secondary anon-approve" href="#title">Approve</a>
@@ -441,6 +457,7 @@ class WPTV_Anon_Upload {
 
 					<div class="row">
 						<p class="label">Language:</p>
+
 						<p class="data">
 							<input type="text" value="<?php echo esc_attr( $meta['language'] ); ?>"/>
 							<a class="button-secondary anon-approve" href="#new-tag-language">Approve</a>
@@ -449,21 +466,23 @@ class WPTV_Anon_Upload {
 
 					<div class="row">
 						<p class="label">Categories:</p>
+
 						<p class="data" id="anon-approve-cats">
 							<?php
-								$cats = preg_replace( '/[^0-9,]+/', '', trim( $meta['categories'], ' ,' ) );
-								$cats = explode( ',', $cats );
-								foreach ( $cats as $cat ) {
-									if ( intval( $cat ) ) {
-										echo '<a href="#in-category-' . $cat . '" class="anon-cat-link" title="Click to approve">Unknown?</a>, ';
-									}
+							$cats = preg_replace( '/[^0-9,]+/', '', trim( $meta['categories'], ' ,' ) );
+							$cats = explode( ',', $cats );
+							foreach ( $cats as $cat ) {
+								if ( intval( $cat ) ) {
+									echo '<a href="#in-category-' . $cat . '" class="anon-cat-link" title="Click to approve">Unknown?</a>, ';
 								}
+							}
 							?>
 						</p>
 					</div>
 
 					<div class="row">
 						<p class="label">Event:</p>
+
 						<p class="data">
 							<input type="text" value="<?php echo esc_attr( $meta['event'] ); ?>"/>
 							<a class="button-secondary anon-approve" href="#new-tag-event">Approve</a>
@@ -471,15 +490,17 @@ class WPTV_Anon_Upload {
 					</div>
 
 					<div class="row">
-						<p class="label">Producer:</p>
+						<p class="label">Producer w.org Username:</p>
+
 						<p class="data">
-							<input type="text" value="<?php echo esc_attr( $meta['producer'] ); ?>"/>
-							<a class="button-secondary anon-approve" href="#new-tag-producer">Approve</a>
+							<input type="text" value="<?php echo esc_attr( $meta['producer_username'] ); ?>"/>
+							<a class="button-secondary anon-approve" href="#wptv-producer-username">Approve</a>
 						</p>
 					</div>
 
 					<div class="row">
 						<p class="label">Speakers:</p>
+
 						<p class="data">
 							<input type="text" value="<?php echo esc_attr( $meta['speakers'] ); ?>"/>
 							<a class="button-secondary anon-approve" href="#new-tag-speakers">Approve</a>
@@ -488,6 +509,7 @@ class WPTV_Anon_Upload {
 
 					<div class="row txtarea">
 						<p class="label">Description:</p>
+
 						<p class="data">
 							<textarea rows="10"><?php echo esc_html( $meta['description'] ); ?></textarea>
 							<a class="button-secondary anon-approve" href="#excerpt">Approve</a>
@@ -496,6 +518,7 @@ class WPTV_Anon_Upload {
 
 					<div class="row">
 						<p class="label">Slides:</p>
+
 						<p class="data">
 							<input type="text" value="<?php echo esc_attr( $meta['slides'] ); ?>"/>
 							<a class="button-secondary anon-approve" href="#wptv-slides-url">Approve</a>
@@ -504,8 +527,10 @@ class WPTV_Anon_Upload {
 
 					<div class="row">
 						<p class="label">Edit attachment:</p>
+
 						<p class="data">
-							<a href="<?php echo esc_url( get_edit_post_link( $meta['attachment_id'] ) ); ?>" target="_blank"><?php echo esc_html( $attachment_post->post_title ); ?></a>
+							<a href="<?php echo esc_url( get_edit_post_link( $meta['attachment_id'] ) ); ?>"
+							   target="_blank"><?php echo esc_html( $attachment_post->post_title ); ?></a>
 						</p>
 					</div>
 				</div>
@@ -539,7 +564,9 @@ class WPTV_Anon_Upload {
 						if (id.indexOf('#new-tag-') != -1) {
 							el.val(target.siblings('input[type="text"]').val());
 							el.siblings('.tagadd').click();
-						} else if ('#title' == id  || '#wptv-slides-url' == id) {
+						} else if ('#title' == id || '#wptv-producer-username' == id) {
+							el.val(target.siblings('input[type="text"]').val());
+						} else if ('#title' == id || '#wptv-slides-url' == id) {
 							el.val(target.siblings('input[type="text"]').val());
 						} else if (id == '#excerpt') {
 							el.val(target.siblings('textarea').val());